==> jc-unilever-domain-0.1.736.1-sources.jar: com/xforceplus/jcunilever/dict/StoreName.java <==
package com.xforceplus.jcunilever.dict;

import com.baomidou.mybatisplus.annotation.EnumValue;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * <p>
 * store_name
 * </p>
 *
 * @author ultraman
 * @since 2024-04-01
 */
public enum StoreName {

    _4463798("4463798", "抖店开放平台测试专用店"),
    _4463799("4463799", "多芬个人护理旗舰店"),
    _25936620("25936620", "多芬个人护理旗舰店"),
    _25099124("25099124", "清扬官方旗舰店"),
    _25932221("25932221", "联合利华洗护清洁旗舰店"),
    _25155430("25155430", "凡士林官方旗舰店"),
    _21774349("21774349", "多芬官方旗舰店"),
    _15176405("15176405", "金纺官方旗舰店"),
    _25160730("25160730", "力士官方旗舰店"),
    _15101803("15101803", "A.H.C官方旗舰店"),
    _91677698("91677698", "regenerate官方旗舰店"),
    _98151635("98151635", "渡美TUNEMAKERS官方旗舰店"),
    _100432082("100432082", "力士洗护发"),
    _102388254("102388254", "多芬洗护发旗舰店"),
    _108527693("108527693", "中华牙膏官方旗舰店"),
    _163050907("163050907", "联合利华身体清洁旗舰店");

    @EnumValue
    @JsonValue
    private final String code;

    private final String desc;

    public String getCode(){
        return this.code;
    }

    public String getDesc(){
        return this.desc;
    }

    StoreName(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    @Override
    public String toString() {
        return this.code;
    }

    public static StoreName fromCode(String code){
        switch(code) {
            case "4463798":
                return _4463798;
            case "4463799":
                return _4463799;
            case "25936620":
                return _25936620;
            case "25099124":
                return _25099124;
            case "25932221":
                return _25932221;
            case "25155430":
                return _25155430;
            case "21774349":
                return _21774349;
            case "15176405":
                return _15176405;
            case "25160730":
                return _25160730;
            case "15101803":
                return _15101803;
            case "91677698":
                return _91677698;
            case "98151635":
                return _98151635;
            case "100432082":
                return _100432082;
            case "102388254":
                return _102388254;
            case "108527693":
                return _108527693;
            case "163050907":
                return _163050907;
            default:
                return null;
        }
    }
}

==> jc-unilever-domain-0.1.744-sources.jar: com/xforceplus/jcunilever/dict/StoreName.java <==
package com.xforceplus.jcunilever.dict;

import com.baomidou.mybatisplus.annotation.EnumValue;
import com.fasterxml.jackson.annotation.JsonValue;

/**
 * <p>
 * store_name
 * </p>
 *
 * @author ultraman
 * @since 2024-03-20
 */
public enum StoreName {

    _4463798("4463798", "抖店开放平台测试专用店"),
    _4463799("4463799", "多芬个人护理旗舰店"),
    _25936620("25936620", "多芬个人护理旗舰店"),
    _25099124("25099124", "清扬官方旗舰店"),
    _25932221("25932221", "联合利华洗护清洁旗舰店"),
    _25155430("25155430", "凡士林官方旗舰店"),
    _21774349("21774349", "多芬官方旗舰店"),
    _15176405("15176405", "金纺官方旗舰店"),
    _25160730("25160730", "力士官方旗舰店"),
    _15101803("15101803", "A.H.C官方旗舰店"),
    _91677698("91677698", "regenerate官方旗舰店"),
    _98151635("98151635", "渡美TUNEMAKERS官方旗舰店"),
    _100432082("100432082", "力士洗护发"),
    _102388254("102388254", "多芬洗护发旗舰店"),
    _108527693("108527693", "中华牙膏官方旗舰店");

    @EnumValue
    @JsonValue
    private final String code;

    private final String desc;

    public String getCode(){
        return this.code;
    }

    public String getDesc(){
        return this.desc;
    }

    StoreName(String code, String desc) {
        this.code = code;
        this.desc = desc;
    }

    @Override
    public String toString() {
        return this.code;
    }

    public static StoreName fromCode(String code){
        switch(code) {
            case "4463798":
                return _4463798;
            case "4463799":
                return _4463799;
            case "25936620":
                return _25936620;
            case "25099124":
                return _25099124;
            case "25932221":
                return _25932221;
            case "25155430":
                return _25155430;
            case "21774349":
                return _21774349;
            case "15176405":
                return _15176405;
            case "25160730":
                return _25160730;
            case "15101803":
                return _15101803;
            case "91677698":
                return _91677698;
            case "98151635":
                return _98151635;
            case "100432082":
                return _100432082;
            case "102388254":
                return _102388254;
            case "108527693":
                return _108527693;
            default:
                return null;
        }
    }
}
